@@ -1,6 +1,6 @@
-from o2sclpy.utils import terminal
+from o2sclpy.utils import terminal_py
 
-ter=terminal()
+ter=terminal_py()
 
 version='0.926'
 
@@ -91,6 +91,24 @@ base_list=[
      " command is invoked "+
      "more than once, then only the last invocation will have any "+
      "effect."],
+    ["cmap","Create a continuous colormap.",
+     "<cmap name> <color 1> <color 2> [color3]...",
+     "Create a new color map named <cmap name> which consists of "+
+     "equal-sized gradients between the specified list of at least "+
+     "two colors. Matplotlib colors, (r,g,b) colors, and xkcd "+
+     "colors are all allowed. For example 'o2graph -cmap c "+
+     "forestgreen \"(0.5,0.5,0.7)\" \"xkcd:light red\" -create "+
+     "table3d x grid:0,40,1 y grid:0,40,1 z \"x+y\" -den-plot z "+
+     "cmap=c -show'."],
+    ["cmap2","Create a colormap.",
+     "<cmap name> <color 1> <color 2> [color3 color4]...",
+     "Create a new color map named <cmap name> which consists of "+
+     "equal-sized gradients between the list of specified color "+
+     "pairs. Matplotlib colors, (r,g,b) colors, and xkcd "+
+     "colors are all allowed. For example 'o2graph -cmap2 c "+
+     "\"(0.5,0.5,0.7)\" \"xkcd:light red\" -create "+
+     "table3d x grid:0,40,1 y grid:0,40,1 z \"x+y\" -den-plot z "+
+     "cmap=c -show'."],
     ["canvas","Create a plotting canvas.","",
      "Create an empty plotting canvas. For example 'o2graph "+
      "-canvas -show'. Typically, 'o2graph' creates "+
@@ -223,7 +241,11 @@ base_list=[
      "command. All arguments are keyword arguments. The kwargs for "+
      "'subadj' are left, right, bottom, top, "+
      "wspace, and hspace. This just a wrapper to the "+
-     "pyplot.subplots_adjust() function."],
+     "pyplot.subplots_adjust() function. Note that, unlike the margin "+
+     "settings for the fig_dict parameter, the values 'right' and 'top' "+
+     "are defined relative to the lower-left corner, so a small right "+
+     "margin is 'right=0.99'. The subplots_adjust() function requires "+
+     "right>left and top>bottom."],
     ["subplots","Create subplots.","<nrows> <ncols> [kwargs]",
      "Create a grid of <nrows> by <ncols> subplots. "+
      "The kwargs currently supported are 'sharex=True|False', "+
@@ -302,6 +324,9 @@ base_list=[
      "word 'end'.\n\n"+
      "Examples are:\n  -yt-ann -text 0.1 0.95 \"Ann. example\" "+
      "color=w,ha=left end"],
+    ["yt-xtitle","Add a x title to a yt render.","",""],
+    ["yt-ytitle","Add a y title to a yt render.","",""],
+    ["yt-ztitle","Add a z title to a yt render.","",""],
     ["yt-arrow","Draw an arrow in the yt volume.",
      "<[x1,y1,z1]> <[x2,y2,z2]> [kwargs]",
      "Draw an arrow from the tail at (x1,y1,z1) to the head at "+
@@ -551,7 +576,14 @@ extra_list=[
      "(for imshow), alpha, vmin, and vmax."],
     ["table3d","den-plot-rgb","Create a (R,G,B) density plot from a table3d.",
      "<slice_r> <slice_g> <slice_b>","Create a density plot from "+
-     "the three specified slices. This command uses imshow()."],
+     "the three specified slices. This command uses imshow(). "+
+     "To directly create a .png file with no axes, use make-png instead."],
+    ["table3d","yt-mesh","","",""],
+    ["table3d","make-png","Create a png file from a table3d object.",
+     "<slice_r> <slice_g> <slice_b> <filename>",
+     "Create a .png file from "+
+     "the three specified table3d slices. This command requires pillow. "+
+     "To create a density-plot with axes instead, use den-plot-rgb."],
     ["hist","plot","Plot the histogram.","[kwargs]",
      "Plot the histogram weights as a function "+
      "of the bin representative values. "+
