@@ -1,7 +1,7 @@
 """
   -------------------------------------------------------------------
 
-  Copyright (C) 2020-2021, Andrew W. Steiner
+  Copyright (C) 2020-2022, Andrew W. Steiner
 
   This file is part of O2scl.
 
@@ -17,6 +17,7 @@
 
   You should have received a copy of the GNU General Public License
   along with O2scl. If not, see <http://www.gnu.org/licenses/>.
+
   -------------------------------------------------------------------
 """
 
@@ -240,7 +241,7 @@ class slack_messenger:
         """
         | Parameters:
         | *message*: string
-        | *err_on_fail*=true: ``bool``
+        | *err_on_fail* =true: ``bool``
         | Returns: a Python int
         """
         message_=ctypes.c_char_p(force_bytes(message))
@@ -353,7 +354,7 @@ class quadratic_real_coeff_gsl:
         return ret
 
 
-class quadratic_real_coeff_gsl2<>:
+class quadratic_real_coeff_gsl2:
     """
     Python interface for O\ :sub:`2`\ scl class ``quadratic_real_coeff_gsl2<>``,
     See
@@ -366,7 +367,7 @@ class quadratic_real_coeff_gsl2<>:
 
     def __init__(self,link,pointer=0):
         """
-        Init function for class quadratic_real_coeff_gsl2<>
+        Init function for class quadratic_real_coeff_gsl2
 
         | Parameters:
         | *link* :class:`linker` object
@@ -375,7 +376,7 @@ class quadratic_real_coeff_gsl2<>:
         """
 
         if pointer==0:
-            f=link.o2scl.o2scl_create_quadratic_real_coeff_gsl2__
+            f=link.o2scl.o2scl_create_quadratic_real_coeff_gsl2_
             f.restype=ctypes.c_void_p
             f.argtypes=[]
             self._ptr=f()
@@ -387,11 +388,11 @@ class quadratic_real_coeff_gsl2<>:
 
     def __del__(self):
         """
-        Delete function for class quadratic_real_coeff_gsl2<>
+        Delete function for class quadratic_real_coeff_gsl2
         """
 
         if self._owner==True:
-            f=self._link.o2scl.o2scl_free_quadratic_real_coeff_gsl2__
+            f=self._link.o2scl.o2scl_free_quadratic_real_coeff_gsl2_
             f.argtypes=[ctypes.c_void_p]
             f(self._ptr)
             self._owner=False
@@ -400,9 +401,9 @@ class quadratic_real_coeff_gsl2<>:
 
     def __copy__(self):
         """
-        Shallow copy function for class quadratic_real_coeff_gsl2<>
+        Shallow copy function for class quadratic_real_coeff_gsl2
         
-        Returns: a quadratic_real_coeff_gsl2<> object
+        Returns: a quadratic_real_coeff_gsl2 object
         """
 
         new_obj=type(self)(self._link,self._ptr)
@@ -416,7 +417,7 @@ class quadratic_real_coeff_gsl2<>:
         | *c2*: ``double``
         | Returns: a Python int, a Python float, a Python float
         """
-        func=self._link.o2scl.o2scl_quadratic_real_coeff_gsl2___solve_r
+        func=self._link.o2scl.o2scl_quadratic_real_coeff_gsl2__solve_r
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double)]
         r1_conv=ctypes.c_double(0)
@@ -434,14 +435,14 @@ class quadratic_real_coeff_gsl2<>:
         | *r2*: :class:`std::complex<double>` object
         | Returns: a Python int
         """
-        func=self._link.o2scl.o2scl_quadratic_real_coeff_gsl2___solve_rc
+        func=self._link.o2scl.o2scl_quadratic_real_coeff_gsl2__solve_rc
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_void_p,ctypes.c_void_p]
         ret=func(self._ptr,a2,b2,c2,r1._ptr,r2._ptr)
         return ret
 
 
-class cubic_real_coeff_cern<>:
+class cubic_real_coeff_cern:
     """
     Python interface for O\ :sub:`2`\ scl class ``cubic_real_coeff_cern<>``,
     See
@@ -454,7 +455,7 @@ class cubic_real_coeff_cern<>:
 
     def __init__(self,link,pointer=0):
         """
-        Init function for class cubic_real_coeff_cern<>
+        Init function for class cubic_real_coeff_cern
 
         | Parameters:
         | *link* :class:`linker` object
@@ -463,7 +464,7 @@ class cubic_real_coeff_cern<>:
         """
 
         if pointer==0:
-            f=link.o2scl.o2scl_create_cubic_real_coeff_cern__
+            f=link.o2scl.o2scl_create_cubic_real_coeff_cern_
             f.restype=ctypes.c_void_p
             f.argtypes=[]
             self._ptr=f()
@@ -475,11 +476,11 @@ class cubic_real_coeff_cern<>:
 
     def __del__(self):
         """
-        Delete function for class cubic_real_coeff_cern<>
+        Delete function for class cubic_real_coeff_cern
         """
 
         if self._owner==True:
-            f=self._link.o2scl.o2scl_free_cubic_real_coeff_cern__
+            f=self._link.o2scl.o2scl_free_cubic_real_coeff_cern_
             f.argtypes=[ctypes.c_void_p]
             f(self._ptr)
             self._owner=False
@@ -488,9 +489,9 @@ class cubic_real_coeff_cern<>:
 
     def __copy__(self):
         """
-        Shallow copy function for class cubic_real_coeff_cern<>
+        Shallow copy function for class cubic_real_coeff_cern
         
-        Returns: a cubic_real_coeff_cern<> object
+        Returns: a cubic_real_coeff_cern object
         """
 
         new_obj=type(self)(self._link,self._ptr)
@@ -505,7 +506,7 @@ class cubic_real_coeff_cern<>:
         | *d3*: ``double``
         | Returns: a Python int, a Python float, a Python float, a Python float
         """
-        func=self._link.o2scl.o2scl_cubic_real_coeff_cern___solve_r
+        func=self._link.o2scl.o2scl_cubic_real_coeff_cern__solve_r
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double)]
         r1_conv=ctypes.c_double(0)
@@ -525,7 +526,7 @@ class cubic_real_coeff_cern<>:
         | *r3*: :class:`std::complex<double>` object
         | Returns: a Python int, a Python float
         """
-        func=self._link.o2scl.o2scl_cubic_real_coeff_cern___solve_rc
+        func=self._link.o2scl.o2scl_cubic_real_coeff_cern__solve_rc
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.POINTER(ctypes.c_double),ctypes.c_void_p,ctypes.c_void_p]
         r1_conv=ctypes.c_double(0)
@@ -625,7 +626,7 @@ class cubic_real_coeff_gsl:
         return ret,r1_conv.value
 
 
-class quartic_real_coeff_cern<>:
+class quartic_real_coeff_cern:
     """
     Python interface for O\ :sub:`2`\ scl class ``quartic_real_coeff_cern<>``,
     See
@@ -638,7 +639,7 @@ class quartic_real_coeff_cern<>:
 
     def __init__(self,link,pointer=0):
         """
-        Init function for class quartic_real_coeff_cern<>
+        Init function for class quartic_real_coeff_cern
 
         | Parameters:
         | *link* :class:`linker` object
@@ -647,7 +648,7 @@ class quartic_real_coeff_cern<>:
         """
 
         if pointer==0:
-            f=link.o2scl.o2scl_create_quartic_real_coeff_cern__
+            f=link.o2scl.o2scl_create_quartic_real_coeff_cern_
             f.restype=ctypes.c_void_p
             f.argtypes=[]
             self._ptr=f()
@@ -659,11 +660,11 @@ class quartic_real_coeff_cern<>:
 
     def __del__(self):
         """
-        Delete function for class quartic_real_coeff_cern<>
+        Delete function for class quartic_real_coeff_cern
         """
 
         if self._owner==True:
-            f=self._link.o2scl.o2scl_free_quartic_real_coeff_cern__
+            f=self._link.o2scl.o2scl_free_quartic_real_coeff_cern_
             f.argtypes=[ctypes.c_void_p]
             f(self._ptr)
             self._owner=False
@@ -672,9 +673,9 @@ class quartic_real_coeff_cern<>:
 
     def __copy__(self):
         """
-        Shallow copy function for class quartic_real_coeff_cern<>
+        Shallow copy function for class quartic_real_coeff_cern
         
-        Returns: a quartic_real_coeff_cern<> object
+        Returns: a quartic_real_coeff_cern object
         """
 
         new_obj=type(self)(self._link,self._ptr)
@@ -690,7 +691,7 @@ class quartic_real_coeff_cern<>:
         | *e4*: ``double``
         | Returns: a Python int, a Python float, a Python float, a Python float, a Python float
         """
-        func=self._link.o2scl.o2scl_quartic_real_coeff_cern___solve_r
+        func=self._link.o2scl.o2scl_quartic_real_coeff_cern__solve_r
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_double)]
         r1_conv=ctypes.c_double(0)
@@ -714,7 +715,7 @@ class quartic_real_coeff_cern<>:
         | *r4*: :class:`std::complex<double>` object
         | Returns: a Python int
         """
-        func=self._link.o2scl.o2scl_quartic_real_coeff_cern___solve_rc
+        func=self._link.o2scl.o2scl_quartic_real_coeff_cern__solve_rc
         func.restype=ctypes.c_int
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_double,ctypes.c_void_p,ctypes.c_void_p,ctypes.c_void_p,ctypes.c_void_p]
         ret=func(self._ptr,a4,b4,c4,d4,e4,r1._ptr,r2._ptr,r3._ptr,r4._ptr)
@@ -1072,7 +1073,7 @@ class hist:
         """
         | Parameters:
         | *x*: ``double``
-        | *val*=1.0: ``double``
+        | *val* =1.0: ``double``
         """
         func=self._link.o2scl.o2scl_hist_update
         func.argtypes=[ctypes.c_void_p,ctypes.c_double,ctypes.c_double]
@@ -1083,7 +1084,7 @@ class hist:
         """
         | Parameters:
         | *i*: ``size_t``
-        | *val*=1.0: ``double``
+        | *val* =1.0: ``double``
         """
         func=self._link.o2scl.o2scl_hist_update_i
         func.argtypes=[ctypes.c_void_p,ctypes.c_size_t,ctypes.c_double]
@@ -1180,18 +1181,4 @@ class hist:
         func(self._ptr)
         return
 
-    @classmethod
-    def init(cls,link,nv,v,n_bins):
-        """
-        Constructor-like class method for hist .
-
-        | Parameters:
-
-        """
-
-        f=link.o2scl.o2scl_hist_init
-        f.restype=ctypes.c_void_p
-        f.argtypes=[ctypes.c_size_t,ctypes.c_std::vector<double>,ctypes.c_size_t]
-        return cls(link,f(nv,v,n_bins))
-
 
