@@ -1,6 +1,6 @@
 #  -------------------------------------------------------------------
 #  
-#  Copyright (C) 2006-2020, Andrew W. Steiner
+#  Copyright (C) 2006-2022, Andrew W. Steiner
 #  
 #  This file is part of O2sclpy.
 #  
@@ -27,7 +27,7 @@ import textwrap
 # For rectangles
 import matplotlib.patches as patches
 
-from o2sclpy.utils import default_plot, string_to_dict, terminal
+from o2sclpy.utils import default_plot, string_to_dict, terminal_py
 from o2sclpy.doc_data import cmaps, new_cmaps
 
 def marker_list():
@@ -36,7 +36,7 @@ def marker_list():
     command-line arguments.
     """
     print('Matplotlib markers supported by O2graph:')
-    ter=terminal()
+    ter=terminal_py()
     print(ter.horiz_line())
     outs='. point'.ljust(20)
     outs=outs+', pixel'.ljust(20)
@@ -342,7 +342,7 @@ def cmap_list_func():
     List the matplotlib and o2sclpy colormaps.
     """
     print('Matplotlib colormaps:')
-    ter=terminal()
+    ter=terminal_py()
     print(ter.horiz_line())
     for category, cmap_list in cmaps:
         list2=''
@@ -541,7 +541,7 @@ def color_list():
     """
     from matplotlib import colors as mcolors
     print('Matplotlib colors:')
-    ter=terminal()
+    ter=terminal_py()
     print(ter.horiz_line())
     base_dict=dict(mcolors.BASE_COLORS)
     css4_dict=dict(**mcolors.CSS4_COLORS)
@@ -594,7 +594,7 @@ def xkcd_colors_list():
     from matplotlib import colors as mcolors
     xkcd_dict=dict(**mcolors.XKCD_COLORS)
     print('XKCD colors:')
-    ter=terminal()
+    ter=terminal_py()
     print(ter.horiz_line())
     # These are commented out for now because
     # o2graph has a hard time with spaces in
