@@ -1,6 +1,6 @@
 #  -------------------------------------------------------------------
 #  
-#  Copyright (C) 2006-2020, Andrew W. Steiner
+#  Copyright (C) 2006-2022, Andrew W. Steiner
 #  
 #  This file is part of O2sclpy.
 #  
@@ -34,6 +34,120 @@ import platform
 import ctypes
 from ctypes.util import find_library
 
+def remove_spaces(string):
+    while len(string)>0 and string[0]==' ':
+        string=string[1:]
+    return string
+
+def doc_replacements(s,base_list_new,ter):
+
+    # Replace commands in base_list_new
+    for i in range(0,len(base_list_new)):
+        s=s.replace('``'+base_list_new[i][0]+'``',
+                    ter.cyan_fg()+ter.bold()+base_list_new[i][0]+
+                    ter.default_fg())
+
+    # For ``code`` formatting
+    s=s.replace(' ``',' ')
+    s=s.replace('`` ',' ')
+    s=s.replace('``, ',', ')
+    s=s.replace('``. ','. ')
+
+    # Combine two spaces to one
+    s=s.replace('  ',' ')
+
+    # For :math:`` equations
+    s=s.replace(' :math:`',' ')
+    s=s.replace('` ',' ')
+    s=s.replace('`.','.')
+    s=s.replace('`',',')
+                    
+    return s
+
+def reformat_python_docs(cmd,doc_str,base_list_new):
+
+    reflist=doc_str.split('\n')
+    
+    for i in range(0,len(reflist)):
+        reflist[i]=remove_spaces(reflist[i])
+        #print(i,'x',reflist[i],'x')
+
+    if len(reflist)<1:
+        return
+
+    if reflist[0]=='':
+        if len(reflist)<2:
+            return
+        doc_str2=reflist[1]
+        for i in range(2,len(reflist)):
+            doc_str2=doc_str2+'\n'+reflist[i]
+    else:
+        doc_str2=reflist[0]
+        for i in range(0,len(reflist)):
+            doc_str2=doc_str2+'\n'+reflist[i]
+
+    reflist2=doc_str2.split('\n\n')
+
+    if False:
+        for i in range(0,len(reflist2)):
+            print(i,'x',reflist2[i],'x')
+    
+    ter=terminal_py()
+    ncols=os.get_terminal_size().columns
+
+    short=''
+    parm_desc=''
+    long_help=''
+
+    # The short description
+    if len(reflist2)>=2:
+        short=reflist2[1]
+
+    # The parameter description
+    if len(reflist2)>=3:
+        parm_desc=reflist2[2].replace('\n',' ')
+
+        parm_desc=parm_desc.replace('  ',' ')
+        sx='Command-line arguments: ``'
+        if parm_desc[0:len(sx)]==sx:
+            parm_desc=parm_desc[len(sx):]
+        if parm_desc[-2:]=='``':
+            parm_desc=parm_desc[0:-2]
+            
+    print('Usage: '+ter.cyan_fg()+ter.bold()+cmd+
+          ter.default_fg()+' '+parm_desc)
+    print('Short description:',short)
+
+    if len(reflist2)>=4:
+        print('')
+        print('Long description:')
+        for j in range(3,len(reflist2)):
+            if len(reflist2[j])>0:
+                long_help=doc_replacements(reflist2[j].replace('\n',' '),
+                                           base_list_new,ter)
+                tmplist=wrap_line(long_help,ncols-1)
+                if j!=3:
+                    print('')
+                for k in range(0,len(tmplist)):
+                    print(tmplist[k])
+
+def string_to_color(str_in):
+    """
+    Convert a string to a color
+    """
+
+    if str_in[0]=='(':
+        temps=str_in[1:len(str_in)-1]
+        temp2=temps.split(',')
+        return (float(temp2[0]),float(temp2[1]),float(temp2[2]))
+    elif str_in[0]=='[':
+        temps=str_in[1:len(str_in)-1]
+        temp2=temps.split(',')
+        return [float(temp2[0]),float(temp2[1]),float(temp2[2]),
+                float(temp2[3])]
+    
+    return str_in
+
 def if_yt_then_Agg(backend,argv):
     # Determine if yt commands are present
             
@@ -46,7 +160,7 @@ def if_yt_then_Agg(backend,argv):
             backend='Agg'
     return backend
 
-def o2scl_get_type(o2scl_hdf,amp):
+def o2scl_get_type(o2scl,amp):
     """
     Get the type of the current object stored in the acol_manager
     pointer
@@ -57,7 +171,7 @@ def o2scl_get_type(o2scl_hdf,amp):
     int_ptr=ctypes.POINTER(ctypes.c_int)
     
     # Set up wrapper for type function
-    type_fn=o2scl_hdf.o2scl_acol_get_type
+    type_fn=o2scl.o2scl_acol_get_type
     type_fn.argtypes=[ctypes.c_void_p,int_ptr,char_ptr_ptr]
     
     # Get current type
@@ -71,12 +185,12 @@ def o2scl_get_type(o2scl_hdf,amp):
         curr_type=curr_type+type_ptr[i]
     return curr_type
 
-def table3d_get_slice(o2scl_hdf,amp,name):
+def table3d_get_slice(o2scl,amp,name):
     """
     Return a slice from the current table3d object stored
     in the acol_manager object 'amp'
     """
-    get_fn=o2scl_hdf.o2scl_acol_get_slice
+    get_fn=o2scl.o2scl_acol_get_slice
     get_fn.argtypes=[ctypes.c_void_p,ctypes.c_char_p,
                      int_ptr,double_ptr_ptr,
                      int_ptr,double_ptr_ptr,double_ptr_ptr]
@@ -92,7 +206,7 @@ def table3d_get_slice(o2scl_hdf,amp,name):
            ctypes.byref(ptrs))
     return (nx,ptrx,ny,ptry,ptrs)
 
-def table_get_column(o2scl_hdf,amp,name,return_pointer=False):
+def table_get_column(o2scl,amp,name,return_pointer=False):
     """
     Return a column from the current table object stored
     in the acol_manager object 'amp'
@@ -104,7 +218,7 @@ def table_get_column(o2scl_hdf,amp,name,return_pointer=False):
     double_ptr_ptr=ctypes.POINTER(double_ptr)
 
     # Function interface
-    get_fn=o2scl_hdf.o2scl_acol_get_column
+    get_fn=o2scl.o2scl_acol_get_column
     get_fn.argtypes=[ctypes.c_void_p,ctypes.c_char_p,
                      int_ptr,double_ptr_ptr]
     get_fn.restype=ctypes.c_int
@@ -145,6 +259,15 @@ def force_bytes(obj):
         return bytes(obj,'utf-8')
     return obj
 
+def force_string(obj):
+    """
+    This function returns the bytes object corresponding to ``obj``
+    in case it is a string using UTF-8. 
+    """
+    if isinstance(obj,numpy.bytes_)==True or isinstance(obj,bytes)==True:
+        return obj.decode('utf-8')
+    return obj
+
 # This function is probably best replaced by get_str_array() below
 #
 # def parse_col_names(dset):
@@ -637,7 +760,7 @@ def string_to_dict(s):
         
     return dct
 
-class terminal:
+class terminal_py:
     """
     Handle vt100 formatting sequences
     """
@@ -832,7 +955,7 @@ def string_equal_dash(str1,str2):
         return True
     return False
 
-def screenify(tlist,ncols=79):
+def screenify_py(tlist,ncols=79):
     maxlen=0
     for i in range(0,len(tlist)):
         if length_without_colors(tlist[i])>maxlen:
@@ -854,4 +977,3 @@ def screenify(tlist,ncols=79):
                 row=row+colt
         output_list.append(row)
     return output_list
-            
